==> onebapp-vue-dev-0.0.1.tgz: package/lib/backend/request.js <==
import ky, { HTTPError } from "ky";
import { getAuthorization } from "./index";
import { BASE_URL } from "./config";
import { InternalServerError } from "./errors/InternalServerError";
import { ServerError } from "./errors/ServerError";
import { ClientError } from "./errors/ClientError";
import { RedirectionError } from "./errors/RedirectionError";
import { ValidationError } from "./errors/ValidationError";
import { BackendError } from "./errors/BackendError";
export const createBackendError = (error) => {
    if (!(error instanceof HTTPError)) {
        const backendError = new BackendError();
        backendError.message = error.message;
        backendError.addTag("previous", error);
        return backendError;
    }
    // @ts-ignore
    const responseJson = error.response.errorBodyJson ?? {};
    // @ts-ignore
    const responseBody = 
    // @ts-ignore
    error.response.errorBodyText ?? error.response.errorBodyJson ?? "[unknown]";
    const request = {
        id: error.response.headers.get("X-Request-Id") || "[empty]",
        method: error.request.method,
        url: error.request.url,
        body: error.options.body,
    };
    const response = {
        status: error.response.status,
        body: responseBody,
    };
    if (response.status === 500) {
        return new InternalServerError(request, response, responseJson?.message ?? error.message);
    }
    else if (response.status > 500) {
        return new ServerError(request, response, responseJson?.message ?? error.message);
    }
    else if (response.status >= 400 && response.status < 500) {
        const clientError = new ClientError(request, response, responseJson?.message ?? error.message);
        if (response.status === 422) {
            return new ValidationError(responseJson.errors ?? responseJson, error.message, request, response);
        }
        return clientError;
    }
    else if (response.status >= 300 && response.status < 400) {
        return new RedirectionError(request, response, responseJson?.message ?? error.message);
    }
    return new BackendError(request, response, error.message);
};
const afterResponseHooks = new Map();
export const setAfterResponseHook = (status, handler) => {
    afterResponseHooks.set(status, handler);
};
export const request = ky.create({
    prefixUrl: BASE_URL,
    retry: 0,
    hooks: {
        beforeRequest: [
            (request) => {
                const auth = getAuthorization();
                if (auth != null && !request.headers.has("Authorization")) {
                    request.headers.set("Authorization", `Bearer ${auth.access_token}`);
                }
            },
        ],
        afterResponse: [
            async (input, options, response) => {
                const isError = !response.ok;
                if (isError) {
                    const contentType = response.headers.get("content-type") || ""; //?.includes('application/json');
                    if (contentType.includes("application/json")) {
                        // @ts-ignore
                        response.errorBodyJson = await response.json();
                    }
                    else if (contentType.includes("text/")) {
                        // @ts-ignore
                        response.errorBodyText = await response.text();
                    }
                }
                // @ts-ignore
                response.requestMethod = options.method;
                // @ts-ignore
                response.requestBody = options.body;
                const handler = afterResponseHooks.get(response.status);
                return handler !== undefined
                    ? handler(input, options, response)
                    : response;
            },
        ],
    },
});

==> onebapp-vue-dev-0.0.10.tgz: package/lib/backend/request.js <==
import ky, { HTTPError } from "ky";
import { getAuthorization } from "./index";
import { BASE_URL } from "./config";
import { InternalServerError } from "./errors/InternalServerError";
import { ServerError } from "./errors/ServerError";
import { ClientError } from "./errors/ClientError";
import { RedirectionError } from "./errors/RedirectionError";
import { ValidationError } from "./errors/ValidationError";
import { BackendError } from "./errors/BackendError";
export const createBackendError = (error) => {
    if (!(error instanceof HTTPError)) {
        const backendError = new BackendError();
        backendError.message = error.message;
        backendError.addTag("previous", error);
        return backendError;
    }
    // @ts-ignore
    const responseJson = error.response.errorBodyJson ?? {};
    // @ts-ignore
    const responseBody = 
    // @ts-ignore
    error.response.errorBodyText ?? error.response.errorBodyJson ?? "[unknown]";
    const request = {
        id: error.response.headers.get("X-Request-Id") || "[empty]",
        method: error.request.method,
        url: error.request.url,
        body: error.options.body,
    };
    const response = {
        status: error.response.status,
        body: responseBody,
    };
    if (response.status === 500) {
        return new InternalServerError(request, response, responseJson?.message ?? error.message);
    }
    else if (response.status > 500) {
        return new ServerError(request, response, responseJson?.message ?? error.message);
    }
    else if (response.status >= 400 && response.status < 500) {
        const clientError = new ClientError(request, response, responseJson?.message ?? error.message);
        if (response.status === 422) {
            return new ValidationError(responseJson.errors ?? responseJson, error.message, request, response);
        }
        return clientError;
    }
    else if (response.status >= 300 && response.status < 400) {
        return new RedirectionError(request, response, responseJson?.message ?? error.message);
    }
    return new BackendError(request, response, error.message);
};
const afterResponseHooks = new Map();
export const setAfterResponseHook = (status, handler) => {
    afterResponseHooks.set(status, handler);
};
export const request = ky.create({
    prefixUrl: BASE_URL,
    retry: 0,
    hooks: {
        beforeRequest: [
            (request) => {
                const auth = getAuthorization();
                if (auth != null && !request.headers.has("Authorization")) {
                    request.headers.set("Authorization", `Bearer ${auth.access_token}`);
                }
            },
        ],
        afterResponse: [
            async (input, options, response) => {
                const isError = !response.ok;
                if (isError) {
                    const contentType = response.headers.get("content-type") || "";
                    if (contentType.includes("application/json")) {
                        // @ts-ignore
                        response.errorBodyJson = await response.json();
                    }
                    else if (contentType.includes("text/")) {
                        // @ts-ignore
                        response.errorBodyText = await response.text();
                    }
                }
                // @ts-ignore
                response.requestMethod = options.method;
                // @ts-ignore
                response.requestBody = options.body;
                const handler = afterResponseHooks.get(response.status);
                return handler !== undefined
                    ? handler(input, options, response)
                    : response;
            },
        ],
    },
});
